## $Id: studylevel.py 10484 2013-08-12 09:25:38Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Container which holds the data of a student study level
and contains the course tickets.
"""
import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.kofa.utils.helpers import attrs_to_fields
from waeup.kofa.students.studylevel import (
    StudentStudyLevel, CourseTicket,
    CourseTicketFactory, StudentStudyLevelFactory)
from kofacustom.nigeria.students.interfaces import (
    INigeriaStudentStudyLevel, IStudentNavigation, INigeriaCourseTicket)


class NigeriaStudentStudyLevel(StudentStudyLevel):
    """This is a container for course tickets.
    """
    grok.implements(INigeriaStudentStudyLevel, IStudentNavigation)
    grok.provides(INigeriaStudentStudyLevel)

NigeriaStudentStudyLevel = attrs_to_fields(
    NigeriaStudentStudyLevel, omit=['total_credits', 'gpa'])

class NigeriaStudentStudyLevelFactory(StudentStudyLevelFactory):
    """A factory for student study levels.
    """

    def __call__(self, *args, **kw):
        return NigeriaStudentStudyLevel()

    def getInterfaces(self):
        return implementedBy(NigeriaStudentStudyLevel)

class NigeriaCourseTicket(CourseTicket):
    """This is a course ticket which allows the
    student to attend the course. Lecturers will enter scores and more at
    the end of the term.

    A course ticket contains a copy of the original course and
    course referrer data. If the courses and/or their referrers are removed, the
    corresponding tickets remain unchanged. So we do not need any event
    triggered actions on course tickets.
    """
    grok.implements(INigeriaCourseTicket, IStudentNavigation)
    grok.provides(INigeriaCourseTicket)

NigeriaCourseTicket = attrs_to_fields(NigeriaCourseTicket)

class NigeriaCourseTicketFactory(CourseTicketFactory):
    """A factory for student study levels.
    """

    def __call__(self, *args, **kw):
        return NigeriaCourseTicket()

    def getInterfaces(self):
        return implementedBy(NigeriaCourseTicket)
