## $Id: test_student.py 8968 2012-07-10 09:26:36Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Tests for students and related.
"""
from datetime import tzinfo
from zope.component.interfaces import IFactory
from zope.interface import verify
from zope.schema.interfaces import ConstraintNotSatisfied
from waeup.kofa.testing import FunctionalTestCase
from kofacustom.nigeria.students.student import NigeriaStudent, NigeriaStudentFactory
from kofacustom.nigeria.students.studycourse import (
    NigeriaStudentStudyCourse, NigeriaStudentStudyCourseFactory)
from kofacustom.nigeria.students.studylevel import (
    NigeriaStudentStudyLevel, NigeriaCourseTicket,
    NigeriaStudentStudyLevelFactory,
    NigeriaCourseTicketFactory)
from kofacustom.nigeria.students.interfaces import (
    INigeriaStudent, INigeriaStudentStudyCourse,
    INigeriaStudentStudyLevel, INigeriaCourseTicket)
from kofacustom.nigeria.testing import FunctionalLayer


class NigeriaStudentFactoryTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        super(NigeriaStudentFactoryTest, self).setUp()
        self.factory = NigeriaStudentFactory()

    def tearDown(self):
        super(NigeriaStudentFactoryTest, self).tearDown()

    def test_interfaces(self):
        verify.verifyClass(IFactory, NigeriaStudentFactory)
        verify.verifyObject(IFactory, self.factory)

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, NigeriaStudent)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(INigeriaStudent)

    def test_is_foreigner(self):
        student = self.factory()
        self.assertRaises(
            ConstraintNotSatisfied, setattr, student, 'nationality', 'XX')
        student.nationality = 'NG'
        self.assertFalse(student.is_foreigner)
        student.nationality = 'DE'
        self.assertTrue(student.is_foreigner)

class NigeriaStudentStudyCourseFactoryTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        super(NigeriaStudentStudyCourseFactoryTest, self).setUp()
        self.factory = NigeriaStudentStudyCourseFactory()

    def tearDown(self):
        super(NigeriaStudentStudyCourseFactoryTest, self).tearDown()

    def test_interfaces(self):
        verify.verifyClass(IFactory, NigeriaStudentStudyCourseFactory)
        verify.verifyObject(IFactory, self.factory)

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, NigeriaStudentStudyCourse)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(INigeriaStudentStudyCourse)

class NigeriaStudentStudyLevelFactoryTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        super(NigeriaStudentStudyLevelFactoryTest, self).setUp()
        self.factory = NigeriaStudentStudyLevelFactory()

    def tearDown(self):
        super(NigeriaStudentStudyLevelFactoryTest, self).tearDown()

    def test_interfaces(self):
        verify.verifyClass(IFactory, NigeriaStudentStudyLevelFactory)
        verify.verifyObject(IFactory, self.factory)

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, NigeriaStudentStudyLevel)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(INigeriaStudentStudyLevel)

class NigeriaCourseTicketFactoryTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        super(NigeriaCourseTicketFactoryTest, self).setUp()
        self.factory = NigeriaCourseTicketFactory()

    def tearDown(self):
        super(NigeriaCourseTicketFactoryTest, self).tearDown()

    def test_interfaces(self):
        verify.verifyClass(IFactory, NigeriaCourseTicketFactory)
        verify.verifyObject(IFactory, self.factory)

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, NigeriaCourseTicket)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(INigeriaCourseTicket)
